@@ -1,17 +1,20 @@
 /* INSTRUCTION TABLE FOR LEXICAL ANALYSIS (DURING ASSEMBLING) */
 
-#include "instr.h"
-#include "z80-asm.h"
+#include "z80-cpu.h"
+#include "instr_token"
 
-/* Be sure table is in alphabetical order !!! */
+/* Be sure table is in alphabetical order in its first attribute !! */
+/* we need this feature for binary search in convert() in asm.c */
 
 const struct seznam_type instruction[N_INSTRUCTIONS]={
 {"ADC", I_ADC},
 {"ADD", I_ADD},
+{"ALIGN",I_ALIGN},
 {"AND", I_AND},
 {"BIT", I_BIT},
 {"CALL", I_CALL},
 {"CCF", I_CCF},
+{"COND",I_COND},
 {"CP", I_CP},
 {"CPD", I_CPD},
 {"CPDR", I_CPDR},
@@ -21,11 +24,16 @@ const struct seznam_type instruction[N_INSTRUCTIONS]={
 {"DAA", I_DAA},
 {"DEC", I_DEC},
 {"DEFB",I_DEFB},
+{"DEFL",I_DEFL},
+{"DEFM",I_DEFM},
 {"DEFS",I_DEFS},
 {"DEFW",I_DEFW},
 {"DI", I_DI},
 {"DJNZ", I_DJNZ},
 {"EI", I_EI},
+{"END", I_END},
+{"ENDC", I_ENDC},
+{"EQU", I_EQU},
 {"EX", I_EX},
 {"EXX", I_EXX},
 {"HALT", I_HALT},
@@ -73,6 +81,7 @@ const struct seznam_type instruction[N_INSTRUCTIONS]={
 {"SCF", I_SCF},
 {"SET", I_SET},
 {"SLA", I_SLA},
+{"SLL", I_SLL},
 {"SRA", I_SRA},
 {"SRL", I_SRL},
 {"SUB", I_SUB},
